searchData={"items":[{"type":"module","title":"Temp","doc":"","ref":"Temp.html"},{"type":"function","title":"Temp.cleanup/2","doc":"Cleans up the temporary files tracked.","ref":"Temp.html#cleanup/2"},{"type":"function","title":"Temp.mkdir/1","doc":"Returns `{:ok, dir_path}` where `dir_path` is the path is the path of the\ncreated temporary directory.\nReturns `{:error, reason}` if a failure occurs.\n\nThe directory is automatically tracked if tracking is enabled.","ref":"Temp.html#mkdir/1"},{"type":"function","title":"Options - Temp.mkdir/1","doc":"See `path/1`.","ref":"Temp.html#mkdir/1-options"},{"type":"function","title":"Temp.mkdir!/1","doc":"Same as `mkdir/1`, but raises an exception on failure. Otherwise, returns\na temporary directory path.","ref":"Temp.html#mkdir!/1"},{"type":"function","title":"Temp.open/2","doc":"Returns `{:ok, fd, file_path}` if no callback is passed, or `{:ok, file_path}`\nif callback is passed, where `fd` is the file descriptor of a temporary file\nand `file_path` is the path of the temporary file.\nWhen no callback is passed, the file descriptor should be closed.\nReturns `{:error, reason}` if a failure occurs.\n\nThe resulting file is automatically tracked if tracking is enabled.","ref":"Temp.html#open/2"},{"type":"function","title":"Options - Temp.open/2","doc":"See `path/1`.","ref":"Temp.html#open/2-options"},{"type":"function","title":"Temp.open!/2","doc":"Same as `open/1`, but raises an exception on failure.","ref":"Temp.html#open!/2"},{"type":"function","title":"Temp.path/1","doc":"Returns a `{:ok, path}` where `path` is a path that can be used freely in the\nsystem temporary directory, or `{:error, reason}` if it fails to get the\nsystem temporary directory.\n\nThis path is not tracked, so any file created will need manually removing, or\nuse `track_file/1` to have it removed automatically.","ref":"Temp.html#path/1"},{"type":"function","title":"Options - Temp.path/1","doc":"The following options can be used to customize the generated path\n\n  * `:prefix` - prepends the given prefix to the path\n\n  * `:suffix` - appends the given suffix to the path,\n    this is useful to generate a file with a particular extension\n\n  * `:basedir` - places the generated file in the designated base directory\n    instead of the system temporary directory","ref":"Temp.html#path/1-options"},{"type":"function","title":"Temp.path!/1","doc":"Same as `path/1`, but raises an exception on failure. Otherwise, returns a temporary path.","ref":"Temp.html#path!/1"},{"type":"function","title":"Temp.track/0","doc":"Returns `:ok` when the tracking server used to track temporary files started properly.","ref":"Temp.html#track/0"},{"type":"function","title":"Temp.track!/0","doc":"Same as `track/0`, but raises an exception on failure. Otherwise, returns `:ok`","ref":"Temp.html#track!/0"},{"type":"function","title":"Temp.track_file/2","doc":"Add a file to the tracker, so that it will be removed automatically or on Temp.cleanup.","ref":"Temp.html#track_file/2"},{"type":"function","title":"Temp.tracked/1","doc":"Return the paths currently tracked.","ref":"Temp.html#tracked/1"},{"type":"type","title":"Temp.options/0","doc":"","ref":"Temp.html#t:options/0"},{"type":"module","title":"Temp.Tracker","doc":"","ref":"Temp.Tracker.html"},{"type":"function","title":"Temp.Tracker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Temp.Tracker.html#child_spec/1"},{"type":"function","title":"Temp.Tracker.init/1","doc":"","ref":"Temp.Tracker.html#init/1"},{"type":"function","title":"Temp.Tracker.put/2","doc":"","ref":"Temp.Tracker.html#put/2"},{"type":"exception","title":"Temp.Error","doc":"","ref":"Temp.Error.html"},{"type":"extras","title":"elixir-temp","doc":"# elixir-temp\n\n[![Elixir CI](https://github.com/danhper/elixir-temp/actions/workflows/ci.yml/badge.svg)](https://github.com/danhper/elixir-temp/actions/workflows/ci.yml)\n[![Module Version](https://img.shields.io/hexpm/v/temp.svg)](https://hex.pm/packages/temp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/temp/)\n[![Total Download](https://img.shields.io/hexpm/dt/temp.svg)](https://hex.pm/packages/temp)\n[![License](https://img.shields.io/hexpm/l/temp.svg)](https://github.com/danhper/elixir-temp/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/danhper/elixir-temp.svg)](https://github.com/danhper/elixir-temp/commits/master)\n\nAn Elixir module to easily create and use temporary files and directories.\nThe module is inspired by [node-temp](https://github.com/bruce/node-temp).","ref":"readme.html"},{"type":"extras","title":"Installation - elixir-temp","doc":"Add the dependency to your `mix.exs` deps:\n\n```elixir\ndefp deps do\n  [{:temp, \"~> 0.4\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - elixir-temp","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Getting a temporary path - elixir-temp","doc":"```elixir\n# just get a path\n{:ok, tmp_path} = Temp.path\n# with a prefix\n{:ok, tmp_path} = Temp.path \"my-prefix\"\n# with prefix and suffix\n{:ok, tmp_path} = Temp.path %{prefix: \"my-prefix\", suffix: \"my-suffix\"}\n# in a non-default tmp_dir\n{:ok, tmp_path} = Temp.path %{prefix: \"my-prefix\", suffix: \"my-suffix\", basedir: \"/my-tmp\"}\n# error on fail\ntmp_path = Temp.path!\n```","ref":"readme.html#getting-a-temporary-path"},{"type":"extras","title":"Using a temporary directory - elixir-temp","doc":"Note that you can use all the options available for `Temp.path` as the first argument.\n\n```elixir\n# tmp dir\n{:ok, dir_path} = Temp.mkdir \"my-dir\"\nIO.puts dir_path\nFile.write Path.join(dir_path, \"file_in_my_dir\"), \"some content\"\n# remove when done\nFile.rm_rf dir_path\n```\n\nYou can use the `Temp.mkdir!` if you prefer to have an error on failure.","ref":"readme.html#using-a-temporary-directory"},{"type":"extras","title":"Using a temporary file - elixir-temp","doc":"Note that you can use all the options available for `Temp.path` as the first argument.\n\n```elixir\n# tmp file\n{:ok, fd, file_path} = Temp.open \"my-file\"\nIO.puts file_path\nIO.write fd, \"some content\"\nFile.close fd\n# remove when done\nFile.rm file_path\n```\n\nYou can also pass a function to `open` and use the file descriptor in it. In this case, the file will be closed automatically.\n\n```elixir\n# tmp file\n{:ok, file_path} = Temp.open \"my-file\", &IO.write(&1, \"some content\")\nIO.puts file_path\nIO.puts File.read!(file_path)\n# remove when done\nFile.rm file_path\n```","ref":"readme.html#using-a-temporary-file"},{"type":"extras","title":"Tracking temporary files - elixir-temp","doc":"By default, you have to cleanup the files by yourself, however, you can tell\n`Temp` to track the temporary files automatically.\nYou just need to call `Temp.track` (or the bang version `Temp.track!`) and you are done.\nTemporary files will be cleaned up automatically when the process exits.\nYou can also call `Temp.cleanup` if you want to clean them before the process exits.\nHere is an example of how to use it:\n\n```elixir\nTemp.track!\n\ndir_path = Temp.mkdir! \"my-dir\"\nFile.write Path.join(dir_path, \"file_in_my_dir\"), \"some content\"\n\nfile_path = Temp.open! \"my-file\", &IO.write(&1, \"some content\")\nIO.puts file_path\n\nIO.puts inspect(Temp.tracked)\n\n# cleanup\nTemp.cleanup\n\ndir_path = Temp.mkdir\n# this will be cleaned up on exit\n```","ref":"readme.html#tracking-temporary-files"},{"type":"extras","title":"License - elixir-temp","doc":"This source code is licensed under the MIT License. Copyright (c) 2015, Daniel\nPerez. All rights reserved.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}